@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,8 +22,7 @@
 #include <QObject>
 #include <QVariantHash>
 
-namespace PimCommon
-{
+namespace PimCommon {
 class GenericGrantleeFormatterPrivate;
 class PIMCOMMON_EXPORT GenericGrantleeFormatter : public QObject
 {
